@@ -209,16 +209,26 @@ class pane(base.pane):
         image = self.wTree.get_widget("contactImage")
         if contact['picture']:
             loader = gtk.gdk.PixbufLoader()
-            if loader.write(contact['picture']) and loader.close():
-                pixbuf = loader.get_pixbuf()
-                image.set_from_pixbuf(pixbuf)
-                image.set_child_visible(True)
-                self.wTree.get_widget('removeImageButton').set_sensitive(True)                
-            else:
-                # can't use .clear() yet, no 2.8...
+            try:
+                if loader.write(contact['picture']) and loader.close():
+                    pixbuf = loader.get_pixbuf()
+                    image.set_from_pixbuf(pixbuf)
+                    image.set_child_visible(True)
+                    self.wTree.get_widget('removeImageButton').set_sensitive(True)
+                else:
+                    # can't use .clear() yet, no 2.8...
+                    image.set_from_stock("ICON_SIZE_BUTTON",1)
+                    image.set_child_visible(False)
+                    self.wTree.get_widget('removeImageButton').set_sensitive(False)
+            except gobject.GError, e:
                 image.set_from_stock("ICON_SIZE_BUTTON",1)
                 image.set_child_visible(False)
-                self.wTree.get_widget('removeImageButton').set_sensitive(False)
+                self.wTree.get_widget('removeImageButton').set_sensitive(True)
+                d = gtk.MessageDialog(None, gtk.DIALOG_MODAL, gtk.MESSAGE_ERROR, gtk.BUTTONS_CLOSE,
+                                      "Error with picture for %s: %s" % (contact, e))
+                d.run()
+                d.destroy()
+                    
         else:
             # can't use .clear() yet, no 2.8...
             image.set_from_stock("ICON_SIZE_BUTTON",1)
